@@ -150,7 +150,7 @@ def create_scores(defaults):
 def create_search(defaults):
     dex_sim = create_example_sims.create_dextran_model(defaults)
 
-    dextran_paths = ['gradient', 'graphSpace', 'mcmc/stage1', 'multistart', 'nsga3', 'scoretest',
+    dextran_paths = ['gradient', 'graphSpace', 'mcmc/stage1', 'multistart', 'nsga3', 'unsga3', 'scoretest',
                      'other/early_stopping', 'other/refine_shape', 'other/refine_sse']
 
     search_dir = defaults.base_dir / "search"
