@@ -58,7 +58,6 @@ def get_times_values(simulation, target, selected=None):
 
     if selected is None:
         selected = target["selected"]
-
     return times[selected], values[selected] * target["factor"]
 
 
@@ -350,8 +349,11 @@ def runExperiment(
     if simulation.is_file:
         os.remove(path)
 
-    simulationFailed = isinstance(simulation.root.output.solution.solution_times, Dict)
+    user_solution_times = simulation.root.input.solver.user_solution_times
+    simulationFailed = len(simulation.root.output.solution.solution_times) != len(user_solution_times)
     if simulationFailed:
+        if not simulation.is_file:
+            path = "dll interface"
         multiprocessing.get_logger().error(
             "%s sim must have failed %s", individual, path
         )
@@ -520,7 +522,9 @@ def update_json_mcmc(settings):
         new_parameters = settings["parameters_mcmc"]
 
         for new, prior in zip(new_parameters, prior_parameters):
-            if new["location"].split("/")[-1] == prior["location"].split("/")[-1]:
+            ok_location = "location" in new and new["location"].split("/")[-1] == prior["location"].split("/")[-1]
+            ok_location_from = "locationFrom" in new and new["locationFrom"].split("/")[-1] == prior["locationFrom"].split("/")[-1]
+            if ok_location or ok_location_from:
                 #update just the location data everthing else needs to remain the same
                 for key, value in new.items():
                     if key not in keep:
